import venusian


class tween_config(object):
    """ A decorator which allows developers to annotate tween factories. """

    venusian = venusian

    def __init__(self, *args, **kwargs):
        self.args = args
        self.kwargs = kwargs

    def __call__(self, wrapped_tween_factory):
        def do_the_thing(context, name, obj):
            module_name = wrapped_tween_factory.__module__
            callable_name = wrapped_tween_factory.__name__
            factory_string = module_name + '.' + callable_name

            context.config.with_package(info.module).add_tween(
                factory_string,
                *self.args,
                **self.kwargs
            )

        info = self.venusian.attach(
            wrapped_tween_factory,
            do_the_thing,
            category='opbeat_pyramid',
        )

        return wrapped_tween_factory



#!/usr/bin/env python


import opbeat_pyramid
import os

from setuptools import setup


here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'README.md')) as f:
    README = f.read()


MODULE_NAME = opbeat_pyramid.__name__


REQUIRES = [
    'pyramid',
    'setuptools>=18',
]


TEST_REQUIRES = REQUIRES + [
    'coveralls',
    'flake8',
    'flake8-print',
    'opbeat',
    'pytest',
    'pytest-cov',
]


setup(
    name=MODULE_NAME,
    version=opbeat_pyramid.__VERSION__,
    description='Provides opbeat instrumentation for your Pyramid projects.',
    long_description=README,
    author='Bailey Stoner',
    author_email='monokrome@monokro.me',
    url='https://github.com/monokrome/opbeat_pyramid',
    keywords='web pyramid pylons',
    packages=[MODULE_NAME],
    include_package_data=True,
    zip_safe=False,
    install_requires=REQUIRES,
    tests_require=REQUIRES,
    test_suite=MODULE_NAME,
    license='MIT',
    classifiers=[
        "Programming Language :: Python",
        "Framework :: Pyramid",
    ],
)
